<?php
/**
 * File importer class. Takes an URL and returns content from that URL.
 *
 * @package    WordPress
 * @subpackage ff-block-gist-embed
 * @author     FrisFruitig <info@frisfruitig.com>
 * @license    https://www.gnu.org/licenses/gpl-2.0.html GPLv2
 * @link       https://www.frisfruitig.com
 * @since      5.0.3
 * @version    1.0.2
 */

namespace FrisFruitig;

/**
 * FileImporter relies on being extended by subclasses
 */
abstract class FileImporter {

	/**
	 * (Remote) URL.
	 *
	 * @var String
	 */
	protected $url;

	/**
	 * File content.
	 *
	 * @var String
	 */
	protected $content = null;


	/**
	 * Constructor.
	 *
	 * @param String $url  URL of the file to import.
	 */
	public function __construct( $url ) {
		$this->url = $url;
		$this->set_content( $this->url );
	}


	/**
	 * Check if requested file is readable.
	 *
	 * @param String $url  Check readability of this (remote) file.
	 * @return Bool        True if file is readable, false if not.
	 */
	protected function is_readable( $url ) {
		$headers = get_headers( $url );
		return stripos( $headers[0], '200 OK' ) ? true : false;
	}


	/**
	 * Store the content of the file if it is readable.
	 *
	 * @return String  Return stored file content to subclasses.
	 */
	protected function set_content() {
		if ( wp_http_validate_url( $this->url ) && $this->is_readable( $this->url ) ) {
			$this->content = wp_remote_get( $this->url );
			return $this->content;
		}
	}


	/**
	 * Get the full content of the file.
	 *
	 * @return String|Mixed  File content.
	 */
	public function get_content() {
		return $this->content;
	}


	/**
	 * TO REMOVE: Get url content.
	 *
	 * @return String  URL.
	 */
	public function get_url() {
		return $this->url;
	}

}
