<?php
/**
 * API call to retrieve files from a GitHub Gist based on a provided URL.
 *
 * @package    WordPress
 * @subpackage ff-block-gist-embed
 * @author     FrisFruitig <info@frisfruitig.com>
 * @license    https://www.gnu.org/licenses/gpl-2.0.html GPLv2
 * @link       https://www.frisfruitig.com
 * @since      5.0.3
 * @version    1.0.2
 */

// Load WordPress to allow usage of library functions.
require_once rtrim( $_SERVER['DOCUMENT_ROOT'], '/' ) . '/wp-load.php'; // phpcs:ignore WordPress.Security.ValidatedSanitizedInput

// Require GistImporter class.
use FrisFruitig\GistImporter as GistImporter;

// Store Gist files and passed url.
$files = array();
$url   = null;

// phpcs:disable WordPress.Security.NonceVerification
if ( isset( $_GET['url'] ) ) {
	$url = esc_url_raw( trim( wp_unslash( $_GET['url'] ) ) ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput
}
// phpcs:enable WordPress.Security.NonceVerification

// Create GistImporter instance if $url is defined, and return a list of files from the provided Gist URL.
// Otherwise, return an error message to the client.
if ( 'string' === gettype( $url ) ) {
	// Only get the filenames of files in the Gist, so we don't bloat up our database with unnecessary code.
	$importer   = new GistImporter( $url );
	$gist_files = $importer->get_filenames();
	// Add unchecked state to each file.
	for ( $i = 0, $count = count( $gist_files ); $i < $count; $i++ ) {
		$gist_files[ $i ]['checked'] = 0;
	}
	$files = $gist_files;
} else {
	$files = array( 'error' => 'No URL provided' );
}

// Output as JSON.
header( 'Content-type: application/json' );
echo wp_json_encode( $files );
