<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package CGB
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Require logic for server-side rendering.
require 'render.php';

/**
 * Enqueue block assets for both frontend + backend.
 *
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function ff_block_gist_embed_assets() { // phpcs:disable
	// Styles.
	wp_enqueue_style(
		'ff_block_gist_embed-style-css', // Handle.
		plugins_url( 'dist/blocks.style.build.css', dirname( __FILE__ ) ), // Block style CSS.
		array( 'wp-editor' ) // Dependency to include the CSS after it.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: File modification time.
	);
}

// Hook: Frontend assets.
add_action( 'enqueue_block_assets', 'ff_block_gist_embed_assets' ); // phpcs:enable

/**
 * Enqueue block assets for backend editor.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function ff_block_gist_embed_editor_assets() { // phpcs:disable
	// Scripts.
	wp_enqueue_script(
		'ff_block_gist_embed-js', // Handle.
		plugins_url( '/dist/blocks.build.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
		true // Enqueue the script in the footer.
	);

	// phpcs:enable
	// Pass data to our script file.
	wp_localize_script(
		'ff_block_gist_embed-js', // Handle.
		'ffGistEmbed', // Javascript object our data is going to be part of.
		array(
			'pluginsUrl' => plugins_url() . '/ff-block-gist-embed',
		)
	);
	// phpcs:disable

	// Styles.
	wp_enqueue_style(
		'ff_block_gist_embed-editor-css', // Handle.
		plugins_url( 'dist/blocks.editor.build.css', dirname( __FILE__ ) ), // Block editor CSS.
		array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'ff_block_gist_embed_editor_assets' );
