<?php
/**
 * Server-side rendering for Gist embeds.
 *
 * @package    WordPress
 * @subpackage ff-block-gist-embed
 * @author     FrisFruitig <info@frisfruitig.com>
 * @license    https://www.gnu.org/licenses/gpl-2.0.html GPLv2
 * @link       https://www.frisfruitig.com
 * @since      5.0.3
 * @version    1.0.2
 */

// Require GistImporter class.
use FrisFruitig\GistImporter as GistImporter;

/**
 * HTML output for Gist embeds.
 *
 * @param Array $attributes  Block attributes.
 * @return String            HTML output.
 */
function ff_render_gist_embeds( $attributes ) {
	// URL needs to be filled in
	if ( ! isset( $attributes['url'] ) ) {
		return;
	}
	// Get content of all files in the Gist.
	$importer   = new GistImporter( $attributes['url'] );
	$raw_import = isset( $attributes['raw'] ) && 1 === $attributes['raw'];
	$contents   = $raw_import ? $importer->get_raw_content() : $importer->get_content();
	// Set the classname for the wrapping element.
	$alignment = isset( $attributes['align'] ) ? "align{$attributes['align']}" : null;
	$classname = "gist {$alignment}";
	// Enqueue stylesheet if needed.
	// Note: For some reason, the `includeCSS` attribute is only saved to the database when its value is `0`.
	if ( ! isset( $attributes['includeCSS'] ) && ! $raw_import ) {
		$stylesheet = $importer->get_stylesheet();
		ff_block_enqueue_gist_stylesheet( "gist-css-{$attributes['url']}", $stylesheet );
	}

	// Wrap HTML with a class to apply styling from the provided stylesheet.
	$html  = "<div class='{$classname}'>";
	$files = json_decode( $attributes['jsonFiles'], true );
	if ( $files ) {
		foreach ( $files as $index => $file ) {
			// Only get and render the content of the file if it is selected.
			$checked = 1 === $file['checked'] ? true : false;
			if ( $checked ) {
				$html .= $contents[ $index ] . '<br />';
			}
		}
	}
	$html .= '</div>';
	return $html;
}

/**
 * Enqueue Gist stylesheet.
 *
 * @param String $handle  Name of the stylesheet.
 * @param String $url     URL of the stylesheet.
 * @param String $deps    Stylesheet dependencies.
 * @param String $ver     Stylesheet version (for cache).
 */
function ff_block_enqueue_gist_stylesheet( $handle, $url, $deps = array(), $ver = '1.0.2' ) {
	wp_enqueue_style( $handle, $url, $deps, $ver );
}

/**
 * Initialize PHP rendering for the dynamic editor block.
 */
function ff_block_gist_embed_init() {
	register_block_type(
		'frisfruitig/block-gist-embed', // Block namespace.
		array(
			'render_callback' => 'ff_render_gist_embeds', // Callback function.
		)
	);
}
// Hook: init.
add_action( 'init', 'ff_block_gist_embed_init' );
